@@ -1,5 +1,6 @@
 ################################################################################
 # Demo of gexf functions - Building a graph from scratch
+# Author: George Vega
 ################################################################################
 
 pause <- function() {  
@@ -13,11 +14,16 @@ mygraph
 
 pause()
 # Adding nodes
-mygraph <- add.gexf.node(mygraph,1,"george")
-mygraph <- add.gexf.node(mygraph,2,"valita")
+mygraph <- add.gexf.node(mygraph,1,"george", vizAtt=list(size=10))
+mygraph <- add.gexf.node(mygraph,2,"valita", vizAtt=list(color=data.frame(20,20,20,1)))
 mygraph <- add.gexf.node(mygraph,3,"pedro")
 mygraph <- add.gexf.node(mygraph,4,"diego")
 
+pause()
+# Adding spells
+mygraph <- add.node.spell(mygraph, 2, start=0, end=10)
+mygraph <- add.node.spell(mygraph, 2, start=15)
+
 pause()
 # Adding edges
 mygraph <- add.gexf.edge(mygraph,1,2)
@@ -36,5 +42,6 @@ mygraph <- rm.gexf.node(mygraph, id="1", rm.edges=T)
 
 mygraph
 pause()
+
 # Removing edge number two
-mygraph <- rm.gexf.edge(mygraph, number=2)
+rm.gexf.edge(mygraph, number=2)
